==> xfxbase-2.3.9%2B1.tar.gz: lib/XfxMenu.dart <==
part of xfxbase;

// import 'package:flutter/foundation.dart';
// import 'package:flutter/material.dart';

// import '../XStylesBase.dart';
// import '../xWidgetsBase.dart';

class XfxMenu extends StatelessWidget {
  final String? label;
  final GestureTapCallback? logOut_OnTap;
  final GestureTapCallback? nameApp_OnTap;
  final Widget? nameApp;
  final String? title;
  XApp? xApp;
  final EdgeInsetsGeometry? padding;
  final AlignmentGeometry? alignment;
  final bool? logOut_Visible;
  final Color? menu_BackGroundColor;
  final Color? logOut_BackGroundColor;
  final Widget? logOut_Text;
  final Widget? logOut_Icon;
  final TextStyle? title_Style;
  final List<XMenuGroup> menuGroups;
  final double? width_menuItems;
  final double? height_menuItems;
  bool pinned_Value;
  late Function() tabLink;
  final void Function()? onPressed_PinnedBTN;

  ///Verrà chiamata ogni volta che lo user Tappa l'item del Menu e deve tornare il Widget da mettere nel relativo XTab csomai fosse da aprire
  late void Function(XMenuItem)? onPressed_MenuItem;
  static double menuItem_WidthDefault = 250;
  Function()? functOnSync;
  //CLASS NEW
  XfxMenu(
    this.menuGroups,
    this.tabLink, {
    this.nameApp,
    this.xApp,
    this.pinned_Value = true,
    this.onPressed_PinnedBTN,
    this.nameApp_OnTap,
    this.height_menuItems,
    this.width_menuItems,
    this.logOut_BackGroundColor,
    this.logOut_Text,
    this.logOut_Icon,
    this.logOut_Visible,
    this.alignment,
    this.menu_BackGroundColor,
    this.label,
    this.title_Style,
    this.title,
    this.padding,
    this.logOut_OnTap,
    this.onPressed_MenuItem,
    this.functOnSync,
  });

  Widget xBuilder_XMenu(XMenuGroup xclMenu, XApp xApp, BuildContext context) {
    return Column(children: [
      XContainerWithLabel(
        xclMenu.label,
        color: xclMenu.color_BTN,
        textStyle: XStyles.xStyTextForLabel(xclMenu.label_Color ?? XColors.foregroundLight),
      ),
      Wrap(
        spacing: 5,
        runSpacing: 5,
        runAlignment: WrapAlignment.center,
        alignment: WrapAlignment.center,
        children: xclMenu.items.map((xclMenuItem) {
          return XBtnbase(
            //margin: EdgeInsets.symmetric(vertical: 5),
            label: xclMenuItem.label,
            label_Color: xclMenuItem.label_Color,
            backGroundColor: xclMenuItem.color_BTN,
            icon: xclMenuItem.icon_BTN,
            icon_Widget: xclMenuItem.image_Icon_BTN != null
                ? Image.memory(
                    xclMenuItem.image_Icon_BTN!,
                    width: 40,
                    height: 40,
                  )
                : null,
            label_Style: XStyles.xStyTextForLargeTitle(xclMenuItem.label_Color),
            width: width_menuItems ?? menuItem_WidthDefault,
            height: height_menuItems,
            onPressed: () {
              //xclMenuItem.onPressed
              if (xclMenuItem.onPressed != null) {
                xclMenuItem.onPressed!(xclMenuItem);
              }
              //onPressed_MenuItem
              else if (onPressed_MenuItem != null) {
                onPressed_MenuItem!(xclMenuItem);
              }
              tabLink();
            },
          );
        }).toList(),
      ),
      Row(
        children: [
          Expanded(
              child: XBtnbase(
            margin: EdgeInsets.symmetric(vertical: 10, horizontal: 40),
            label: "Sincronizza",
            label_Color: Colors.red,
            backGroundColor: Color.fromARGB(255, 58, 58, 58),
            icon: Icons.refresh,
            label_Style: XStyles.xStyTextForLargeTitle(Colors.red),
            width: width_menuItems ?? menuItem_WidthDefault,
            height: height_menuItems,
            onPressed: () {
              if (functOnSync != null) {
                functOnSync!();
              }
            },
          ))
        ],
      ),
      Row(children: [
        Expanded(
            child: Container(
                child: XBtnbase(
                    margin: EdgeInsets.symmetric(vertical: 10, horizontal: 40),
                    label: "Font Editor",
                    label_Color: Colors.purple,
                    backGroundColor: Color.fromARGB(255, 58, 58, 58),
                    icon: Icons.settings,
                    label_Style: XStyles.xStyTextForLargeTitle(Colors.purple),
                    width: width_menuItems ?? menuItem_WidthDefault,
                    height: height_menuItems,
                    onPressed: () async {
                      TextEditingController textController = TextEditingController(text: xApp.KforScale.toString());
                      double _currentValue = 70;
                      double _markerValue = 70;
                      double _firstMarkerSize = 10;
                      String _annotationValue = '70';
                      var res = await showDialog<bool?>(
                          context: context,
                          builder: (context) {
                            return StatefulBuilder(builder: (context, setState) {
                              double width = MediaQuery.of(context).size.width;

                              //Da modificare per fare i font
                              void handlePointerValueChanged(double value) {
                                if (value.toInt() > 8) {
                                  setState(() {
                                    _currentValue = value.roundToDouble();

                                    textController.text = (_currentValue / 100).toString(); //TODO da vedere come fare i calcoli

                                    final int currentValue = _currentValue.toInt();
                                    _annotationValue = '$currentValue';
                                    _markerValue = _currentValue - 2;
                                  });
                                }
                              }

                              /// Pointer dragging is canceled when dragging pointer value is less than 7.
                              void handlePointerValueChanging(ValueChangingArgs args) {
                                if (args.value.toInt() <= 8) {
                                  args.cancel = true;
                                }
                              }

                              return Container(
                                  margin: EdgeInsets.symmetric(horizontal: 20),
                                  child: XAlertDialog(
                                      colorBackGround: Colors.grey[900],
                                      height: MediaQuery.of(context).size.height / 2,
                                      title_Text: "Scegli la tua grandezza del testo:",
                                      content_insetPadding: EdgeInsets.all(0),
                                      btnYES_label: "Salva",
                                      btnNO_label: "Annulla",
                                      child: Column(children: <Widget>[
                                        Expanded(
                                          flex: 7,
                                          child: SfRadialGauge(axes: <RadialAxis>[
                                            RadialAxis(
                                              minimum: 0.6, maximum: 2.1,
                                              axisLineStyle: const AxisLineStyle(thickness: 0.2, thicknessUnit: GaugeSizeUnit.factor),
                                              showTicks: false,
                                              showLastLabel: true,
                                              //style delle tacchette interne
                                              axisLabelStyle: GaugeTextStyle(color: XColors.foregroundLight, fontSize: 16 * XStyles.KforScale),
                                              onAxisTapped: handlePointerValueChanged,
                                              pointers: <GaugePointer>[
                                                //streiscia da tappare e fare lo slide
                                                RangePointer(
                                                  value: _currentValue,
                                                  onValueChanged: handlePointerValueChanged,
                                                  onValueChangeEnd: handlePointerValueChanged,
                                                  onValueChanging: handlePointerValueChanging,
                                                  enableDragging: true,
                                                  width: 0.2,
                                                  sizeUnit: GaugeSizeUnit.factor,
                                                ),
                                                //Pallino bianco dentro la striscia da tappare
                                                MarkerPointer(
                                                  value: _markerValue,
                                                  color: Colors.white,
                                                  markerHeight: _firstMarkerSize,
                                                  markerWidth: _firstMarkerSize,
                                                  markerType: MarkerType.circle,
                                                ),
                                              ],
                                              //Percentuale interna allo slider
                                              annotations: <GaugeAnnotation>[
                                                GaugeAnnotation(
                                                    widget: Row(
                                                      mainAxisSize: MainAxisSize.min,
                                                      children: <Widget>[Text('$_annotationValue%', style: XStyles.xStyTextForSubDescr())],
                                                    ),
                                                    positionFactor: 0.13,
                                                    angle: 0)
                                              ],
                                            )
                                          ]),
                                        ),
                                        //Slider orizzontale sotto alla chart
                                        Expanded(
                                            flex: 3,
                                            child: SizedBox(
                                              width: width - 50,
                                              child: Slider(
                                                activeColor: const Color(0xFF02AAB0),
                                                inactiveColor: const Color(0xFF00CDAC),
                                                min: 7,
                                                max: 100,
                                                onChanged: handlePointerValueChanged,
                                                value: _currentValue,
                                              ),
                                            )),
                                      ]),
                                      btnYES_OnPressed: () {
                                        Navigator.pop(context, true);
                                      },
                                      btnNO_OnPressed: () {
                                        Navigator.pop(context, false);
                                      }));
                            });
                          });
                      if (res != null && res) {
                        xApp.KforScale = double.parse(textController.text);
                      }
                    })))
      ])
    ]);
  }

  @override
  Widget build(BuildContext context) {
    return Drawer(
        width: MediaQuery.of(context).size.width < XUtils.widthMin_Layout ? (MediaQuery.of(context).size.width - 10) : 350,
        child: Container(
          margin: EdgeInsets.only(right: 10),
          padding: EdgeInsets.only(top: 20),
          color: menu_BackGroundColor ?? Colors.white,
          child: Column(children: [
            SizedBox(height: 20),
            GestureDetector(
              onTap: () {
                onPressed_PinnedBTN != null ? onPressed_PinnedBTN!() : null;
              },
              child: Row(children: [
                logOut_Visible ?? false
                    ? XBtnbase(
                        margin: EdgeInsets.symmetric(horizontal: 8),
                        icon: Icons.power_settings_new,
                        width: 50,
                        height: 50,
                        onPressed: logOut_OnTap,
                        icon_Color: Colors.red,
                      )
                    : Container(),
                title != ""
                    ? Expanded(
                        child: Container(
                            color: Colors.transparent,
                            alignment: Alignment.center,
                            margin: EdgeInsets.only(left: 10),
                            child: Text(
                              title!,
                              style: title_Style ?? XStyles.xStyleText(fontSize: 12, colorText: XColors.backgroundDark, letterSpacing: 1.5),
                            )))
                    : Expanded(child: Container()),
                XBtnbase(
                    icon: MediaQuery.of(context).size.width < XUtils.widthMin_Layout ? Icons.close : (pinned_Value ? Icons.arrow_back_ios : Icons.arrow_forward_ios_rounded),
                    icon_Color: XColors.backgroundLight,
                    width: 40,
                    height: 40,
                    onPressed: () {
                      onPressed_PinnedBTN != null ? onPressed_PinnedBTN!() : null;
                    })
              ]),
            ),
            Expanded(
                child: SingleChildScrollView(
              child: Column(
                children: [
                  Wrap(spacing: 5, runSpacing: 5, alignment: WrapAlignment.start, children: menuGroups.map((xclMenu) => xBuilder_XMenu(xclMenu, xApp!, context)).toList()),
                ],
              ),
            )),
            SizedBox(height: 15)
          ]),
        ));
  }
}

class XMenuGroup {
  String key;
  int? idx;
  String? label;
  List<XMenuItem> items = List<XMenuItem>.empty(growable: true);
  Color? label_Color;
  Color? color_BTN;
  IconData? icon_BTN;
  Uint8List? image_Icon_BTN;
  bool expanded = true;
  XMenuGroup(
    this.key, {
    this.label,
    this.idx,
    this.label_Color,
    this.color_BTN,
    this.icon_BTN,
    this.image_Icon_BTN,
    expanded,
    required this.items,
  });
  addMenuItem(XMenuItem item) {
    this.items.add(item);
  }
}

class XMenuItem {
  String key;
  int? idx;
  String? label;
  Color? label_Color;
  Color? color_BTN;
  IconData? icon_BTN;
  Uint8List? image_Icon_BTN;
  XMenuGroup? parent;

  Function(XMenuItem)? onPressed;

  ///uso futuro
  bool active = true;

  XMenuItem(
    this.key, {
    this.label,
    this.idx,
    this.label_Color,
    this.color_BTN,
    this.onPressed,
    this.icon_BTN,
    this.image_Icon_BTN,
    this.parent,
  });
}

==> xfxbase-2.6.2%2B1.tar.gz: lib/XfxMenu.dart <==
part of xfxbase;

// import 'package:flutter/foundation.dart';
// import 'package:flutter/material.dart';

// import '../XStylesBase.dart';
// import '../xWidgetsBase.dart';

class XfxMenu extends StatelessWidget {
  final String? label;
  final GestureTapCallback? logOut_OnTap;
  final GestureTapCallback? nameApp_OnTap;
  final Widget? nameApp;
  final String? title;
  XApp? xApp;
  final EdgeInsetsGeometry? padding;
  final AlignmentGeometry? alignment;
  final bool? logOut_Visible;
  final Color? menu_BackGroundColor;
  final Color? logOut_BackGroundColor;
  final Widget? logOut_Text;
  final Widget? logOut_Icon;
  final Widget? bottomArea_Widget;
  final TextStyle? title_Style;
  final List<XMenuGroup> menuGroups;
  final double? width_menuItems;
  final double? height_menuItems;
  bool pinned_Value;
  late Function() tabLink;
  late Function() fontChange;
  final void Function()? onPressed_PinnedBTN;

  ///Verrà chiamata ogni volta che lo user Tappa l'item del Menu e deve tornare il Widget da mettere nel relativo XTab csomai fosse da aprire
  late void Function(XMenuItem)? onPressed_MenuItem;
  static double menuItem_WidthDefault = 250;
  Function()? functOnSync;
  bool syncWithServer;
  //CLASS NEW
  XfxMenu(
    this.menuGroups,
    this.tabLink,
    this.fontChange, {
    this.nameApp,
    this.xApp,
    this.bottomArea_Widget,
    this.pinned_Value = true,
    this.onPressed_PinnedBTN,
    this.nameApp_OnTap,
    this.height_menuItems,
    this.width_menuItems,
    this.logOut_BackGroundColor,
    this.logOut_Text,
    this.logOut_Icon,
    this.logOut_Visible,
    this.alignment,
    this.menu_BackGroundColor,
    this.label,
    this.title_Style,
    this.title,
    this.padding,
    this.logOut_OnTap,
    this.onPressed_MenuItem,
    this.functOnSync,
    this.syncWithServer = false,
  });

  Widget xBuilder_XMenu(XMenuGroup xclMenu, XApp xApp, BuildContext context) {
    return Column(children: [
      XContainerWithLabel(
        xclMenu.label,
        color: xclMenu.color_BTN,
        textStyle: XStyles.xStyleText(fontSize: 20 / xApp.KforScale, colorText: xclMenu.label_Color ?? XColors.foregroundLight),
        //textStyle: XStyles.xStyTextForLabel(xclMenu.label_Color ?? XColors.foregroundLight),
      ),
      Stack(
        alignment: Alignment.center,
        children: [
          Column(children: [
            Wrap(
              spacing: 5,
              runSpacing: 5,
              runAlignment: WrapAlignment.center,
              alignment: WrapAlignment.center,
              children: xclMenu.items.map((xclMenuItem) {
                return XBtnbase(
                  //margin: EdgeInsets.symmetric(vertical: 5),
                  label: xclMenuItem.label,
                  label_Color: xclMenuItem.label_Color,
                  backGroundColor: xclMenuItem.color_BTN,
                  icon: xclMenuItem.icon_BTN,
                  icon_Widget: xclMenuItem.image_Icon_BTN != null
                      ? Image.memory(
                          xclMenuItem.image_Icon_BTN!,
                          width: 40,
                          height: 40,
                        )
                      : null,
                  label_Style: XStyles.xStyTextForLargeTitle(xclMenuItem.label_Color),
                  width: width_menuItems ?? menuItem_WidthDefault,
                  height: height_menuItems,
                  onPressed: () {
                    //xclMenuItem.onPressed
                    if (xclMenuItem.onPressed != null) {
                      xclMenuItem.onPressed!(xclMenuItem);
                    }
                    //onPressed_MenuItem
                    else if (onPressed_MenuItem != null) {
                      onPressed_MenuItem!(xclMenuItem);
                    }
                    tabLink();
                  },
                );
              }).toList(),
            ),
            Row(
              children: [
                Expanded(
                    child: XBtnbase(
                  margin: EdgeInsets.symmetric(vertical: 10, horizontal: 40),
                  label: "Sincronizza",
                  label_Color: Colors.red,
                  backGroundColor: Color.fromARGB(255, 58, 58, 58),
                  icon: Icons.refresh,
                  label_Style: XStyles.xStyTextForLargeTitle(Colors.red),
                  width: width_menuItems ?? menuItem_WidthDefault,
                  height: height_menuItems,
                  onPressed: functOnSync != null
                      ? () {
                          functOnSync!();
                        }
                      : null,
                ))
              ],
            ),
            Row(children: [
              Expanded(child: Container(child: XBtnbase(margin: EdgeInsets.symmetric(vertical: 10, horizontal: 40), label: "Font Editor", label_Color: Colors.purple, backGroundColor: Color.fromARGB(255, 58, 58, 58), icon: Icons.settings, label_Style: XStyles.xStyTextForLargeTitle(Colors.purple), width: width_menuItems ?? menuItem_WidthDefault, height: height_menuItems, onPressed: fontChange))),
            ]),
            Row(children: [Expanded(child: bottomArea_Widget ?? Container())])
          ]),
          syncWithServer ? Container(color: Colors.black.withAlpha(180), width: width_menuItems, height: MediaQuery.of(context).size.height / 1.5, child: XStatefulWidgetBase.LoaderIndicator(syncWithServer, label: "...caricamento dei dati...")) : Container(),
        ],
      ),
    ]);
  }

  @override
  Widget build(BuildContext context) {
    return Drawer(
        width: MediaQuery.of(context).size.width < XUtils.widthMin_Layout ? (MediaQuery.of(context).size.width - 10) : 350,
        child: Container(
          margin: EdgeInsets.only(right: 10),
          padding: EdgeInsets.only(top: 20),
          color: menu_BackGroundColor ?? Colors.white,
          child: Column(children: [
            SizedBox(height: 20),
            GestureDetector(
              onTap: () {
                onPressed_PinnedBTN != null ? onPressed_PinnedBTN!() : null;
              },
              child: Row(children: [
                logOut_Visible ?? false
                    ? XBtnbase(
                        margin: EdgeInsets.symmetric(horizontal: 8),
                        icon: Icons.power_settings_new,
                        width: 50,
                        height: 50,
                        onPressed: logOut_OnTap,
                        icon_Color: Colors.red,
                      )
                    : Container(),
                title != ""
                    ? Expanded(
                        child: Container(
                            color: Colors.transparent,
                            alignment: Alignment.center,
                            margin: EdgeInsets.only(left: 10),
                            child: Text(
                              title!,
                              style: title_Style ?? XStyles.xStyleText(fontSize: 12, colorText: XColors.backgroundDark, letterSpacing: 1.5),
                            )))
                    : Expanded(child: Container()),
                XBtnbase(
                    icon: MediaQuery.of(context).size.width < XUtils.widthMin_Layout ? Icons.close : (pinned_Value ? Icons.arrow_back_ios : Icons.arrow_forward_ios_rounded),
                    icon_Color: XColors.backgroundLight,
                    width: 40,
                    height: 40,
                    onPressed: () {
                      onPressed_PinnedBTN != null ? onPressed_PinnedBTN!() : null;
                    })
              ]),
            ),
            Expanded(
                child: SingleChildScrollView(
              child: Column(
                children: [
                  Wrap(spacing: 5, runSpacing: 5, alignment: WrapAlignment.start, children: menuGroups.map((xclMenu) => xBuilder_XMenu(xclMenu, xApp!, context)).toList()),
                ],
              ),
            )),
            SizedBox(height: 15)
          ]),
        ));
  }
}

class XMenuGroup {
  String key;
  int? idx;
  String? label;
  List<XMenuItem> items = List<XMenuItem>.empty(growable: true);
  Color? label_Color;
  Color? color_BTN;
  IconData? icon_BTN;
  Uint8List? image_Icon_BTN;
  bool expanded = true;
  XMenuGroup(
    this.key, {
    this.label,
    this.idx,
    this.label_Color,
    this.color_BTN,
    this.icon_BTN,
    this.image_Icon_BTN,
    expanded,
    required this.items,
  });
  addMenuItem(XMenuItem item) {
    this.items.add(item);
  }
}

class XMenuItem {
  String key;
  int? idx;
  String? label;
  Color? label_Color;
  Color? color_BTN;
  IconData? icon_BTN;
  Uint8List? image_Icon_BTN;
  XMenuGroup? parent;

  Function(XMenuItem)? onPressed;

  ///uso futuro
  bool active = true;

  XMenuItem(
    this.key, {
    this.label,
    this.idx,
    this.label_Color,
    this.color_BTN,
    this.onPressed,
    this.icon_BTN,
    this.image_Icon_BTN,
    this.parent,
  });
}
